@@ -1,4 +1,4 @@
-# $Id: ZapListings.pm,v 1.54 2003/08/26 21:00:12 epaepa Exp $
+# $Id: ZapListings.pm,v 1.62 2003/09/13 19:34:56 epaepa Exp $
 
 #
 # Special thanks to Stephen Bain for helping me play catch-up with
@@ -75,7 +75,7 @@ sub summarize($)
     my $self=shift;
 
     if ( defined($self->{Cell}) ) {
-	#main::errorMessage("warning: cell in row never closed, shouldn't happen\n");
+	#warn("warning: cell in row never closed, shouldn't happen\n");
 	return("");
 	#push(@{$self->{Row}}, @{$self->{Cell}->{things}});
 	#delete($self->{Cell});
@@ -103,7 +103,7 @@ sub getSRC($$)
     my @arr=@{$self->{Row}};
     my $thing=$arr[$index-1];
 
-    #main::errorMessage("item $index : ".XMLTV::ZapListings::dumpMe($thing)."\n");
+    #warn("item $index : ".XMLTV::ZapListings::dumpMe($thing)."\n");
     if ( $thing->{starttag}=~m/img/io ) {
 	return($thing->{attr}->{src}) if ( defined($thing->{attr}->{src}) );
 	return($thing->{attr}->{SRC}) if ( defined($thing->{attr}->{SRC}) );
@@ -118,7 +118,7 @@ sub getHREF($$)
     my @arr=@{$self->{Row}};
     my $thing=$arr[$index-1];
 
-    #main::errorMessage("item $index : ".XMLTV::ZapListings::dumpMe($thing)."\n");
+    #warn("item $index : ".XMLTV::ZapListings::dumpMe($thing)."\n");
     if ( $thing->{starttag}=~m/a/io) {
 	return($thing->{attr}->{href}) if ( defined($thing->{attr}->{href}) );
 	return($thing->{attr}->{HREF}) if ( defined($thing->{attr}->{HREF}) );
@@ -152,7 +152,7 @@ sub new
 				  env_proxy => 1,
 				  timeout => 180);
     bless ($self, $class);
-    $self->agent('xmltv/0.5.17');
+    $self->agent('xmltv/0.5.18');
     return $self;
 }
 
@@ -182,7 +182,7 @@ sub new
     $code=$self->{ZipCode} if ( defined($self->{ZipCode}) );
 
     if ( !defined($code) ) {
-      main::errorMessage("ZapListings::new requires PostalCode or ZipCode defined\n");
+      warn("ZapListings::new requires PostalCode or ZipCode defined\n");
 	exit(1);
     }
     $self->{GeoCode}=$code;
@@ -225,7 +225,7 @@ sub getForms($)
 	$start=index($content, "<FORM") if ( $start == -1 );
 
 	if ( $start == -1 ) {
-	    $start=index($content, $1) if ( $start=~m/(<FORM)/ios );
+	    $start=index($content, $1) if ( $content=~m/(<FORM)/ios );
 	}
 	last if ( $start == -1 );
 
@@ -235,7 +235,7 @@ sub getForms($)
 	$end=index($insideContent, "</FORM>") if ( $end == -1 );
 
 	if ( $end == -1 ) {
-	    $end=index($content, $1) if ( $end=~m/(<FORM)/ios );
+	    $end=index($insideContent, $1) if ( $insideContent=~m/(<FORM)/ios );
 	}
 	last if ( $end == -1 );
 
@@ -246,7 +246,11 @@ sub getForms($)
 	$insideContent=substr($insideContent, 0, $end);
 	#print STDERR "inside = $insideContent\n";
 
+	# Make sure the loop always terminates.
+	my $oldLength = length $content;
 	$content=substr($content, $start+$end);
+	die "failed to trim content (start $start, end $end after start): $content"
+	  unless length $content < $oldLength;
 
 	$insideContent=~s/^<form\s*([^>]+)>(.*)<\/form>$//ios;
 	my $formAttrs=$1;
@@ -301,7 +305,12 @@ sub getForms($)
 		my $above=substr($insideForm, 0, $start);
 		
 		my $ntext=substr($insideForm, $start, $end);
+
+		# Make sure the loop always terminates.
+		my $oldLength = length $insideForm;
 		$insideForm=$above.substr($insideForm, $end);
+		die "failed to trim $insideForm"
+		  unless length $insideForm < $oldLength;
 
 		while ( $ntext=~s/^<select\s*([^>]+)>(.*)(?=<\/select>)//ios ) {
 		    my $selectAttrs=$1;
@@ -537,7 +546,10 @@ sub Form2Request($$)
     my $self=shift;
     my $form=shift;
 
-    return(undef) if ( !defined($form->{attrs}) );
+    if ( !defined($form->{attrs}) ) {
+	warn "no 'attrs' key in form passed in";
+	return undef;
+    }
 
     my $button;
     my @pairs;
@@ -550,8 +562,7 @@ sub Form2Request($$)
 
     for my $input (@{$form->{inputs}}) {
 	if ( !defined($input->{type}) ) {
-	  main::errorMessage("zap2it form 'input' missing type");
-	    
+	    warn("zap2it form 'input' missing type");
 	    return(undef);
 	}
 	if ( $input->{type} eq "submit" ||
@@ -574,19 +585,18 @@ sub Form2Request($$)
 		    $input->{value}=$self->{formSettings}->{$input->{name}};
 		}
 		else {
-		  main::errorMessage("zap2it form has input '$input->{name}' we don't have a value for");
-		    
+		    warn("zap2it form has input '$input->{name}' we don't have a value for");
 		    return(undef);
 		}
 	    }
 	}
 	if ( $input->{type} eq "image" ) {
 	    if ( defined $input->{name} ) {
-	    push(@pairs, $input->{name}.".x");
-	    push(@pairs, "1");
-	    push(@pairs, $input->{name}.".y");
-	    push(@pairs, "1");
-	}
+		push(@pairs, $input->{name}.".x");
+		push(@pairs, "1");
+		push(@pairs, $input->{name}.".y");
+		push(@pairs, "1");
+	    }
 	}
 	else {
 	    push(@pairs, $input->{name});
@@ -603,7 +613,7 @@ sub Form2Request($$)
 		}
 		else {
 		    my $default = 0;
-		  opt:
+	       opt:
 		    for my $option (@{$select->{options}}) {
 			if ( defined $option->{selected} ) {
 			    $default = 1;
@@ -617,14 +627,14 @@ sub Form2Request($$)
 			}
 		    }
 		    if (! $default) {
-		  main::errorMessage("zap2it form has select '$name' we don't have a value for");
+			warn("zap2it form has select '$name' we don't have a value for");
 		    
-		    return(undef);
+			return(undef);
+		    }
 		}
 	    }
 	}
     }
-    }
 
     if ( $form->{attrs}->{method} eq "get" ) {
 	my $url="$form->{attrs}->{action}";
@@ -633,12 +643,18 @@ sub Form2Request($$)
 	while (scalar(@pairs)) {
 	    if ($args eq "") {
 		$args.="?".pop(@pairs)."=".pop(@pairs);
-	    } else {
+	    }
+	    else {
 		$args.="&".pop(@pairs)."=".pop(@pairs);
 	    }
 	}
 	$url.=$args;
-	return(GET(URI->new_abs($url, $self->{formSettings}->{urlbase})));
+	my $uri = URI->new_abs($url, $self->{formSettings}->{urlbase});
+	die "could not make URI from $url and $self->{formSettings}->{urlbase}"
+	     if not $uri;
+	my $got = GET($uri);
+	warn "could not get $uri" if not defined $got;
+	return $got;
     }
     elsif ( $form->{attrs}->{method} eq "post" ) {
 	my $uri = URI->new('http:');
@@ -656,6 +672,7 @@ sub Form2Request($$)
 	return($req)
     }
     else {
+	warn "bad method in form passed in: $form->{attrs}->{method}";
 	return(undef);
     }
 }
@@ -663,6 +680,7 @@ sub Form2Request($$)
 sub doRequest($$$)
 {
     my ($ua, $req, $debug)=@_;
+    die if not $req;
     my $cookie_jar=$ua->cookie_jar();
 
     if ( $debug ) {
@@ -714,7 +732,9 @@ sub getCurrentReleaseInfo($$)
     my $debug=shift;
     my $ua=XMLTV::ZapListings::RedirPostsUA->new();
 
-    my $res=doRequest($ua, GET($url), $debug);
+    my $req = GET($url);
+    die "cannot make request object for $url" if not $req;
+    my $res=doRequest($ua, $req, $debug);
     if ( !defined($res) ) {
 	return(undef);
     }
@@ -757,6 +777,7 @@ sub getZipCodeForm($$$)
     $self->{formSettings}->{zipcode}=$geocode;
     $self->{formSettings}->{urlbase}=$urlbase;
     $self->{formSettings}->{listingssite}="tvl";
+    $self->{formSettings}->{category}="0";       # all categories
 
     # this is such a HACK, forcing the method change to "get"... but it
     # fixes things...so we go with the flow
@@ -770,13 +791,14 @@ sub initGeoCodeAndGetProvidersList($$)
     my $geocode=shift;
 
     my $req = GET("http://www.zap2it.com/index");
+    die "cannot make request object for http://www.zap2it.com/index" if not $req;
     my $res=&doRequest($self->{ua}, $req, $self->{Debug});
 
     if ( !$res->is_success ) {
-        main::errorMessage("request failed with code: ".$res->code().":".HTTP::Status::status_message($res->code())."\n");
-	main::errorMessage("if problem persists, examine browser settings and\n");
-	main::errorMessage("try setting 'http_proxy' environment variable\n");
-	main::errorMessage("otherwise post problem to xmltv-users\@lists.sf.net for assistance\n");
+        warn("request failed with code: ".$res->code().":".HTTP::Status::status_message($res->code())."\n");
+	warn("if problem persists, examine browser settings and\n");
+	warn("try setting 'http_proxy' environment variable\n");
+	warn("otherwise post problem to xmltv-users\@lists.sf.net for assistance\n");
 	return(-1);
     }
 
@@ -797,12 +819,13 @@ sub initGeoCodeAndGetProvidersList($$)
     }
 
     if ( !defined($self->{ZipCodeForm}) ) {
-      main::errorMessage("zap2it top level web page doesn't have a zipcode form\n");
+      warn("zap2it top level web page doesn't have a zipcode form\n");
 	return(-1);
     }
 
     $req=$self->getZipCodeForm($geocode, $res->base());
     if ( !defined($req) ) {
+	warn "failed to get zip code form for $geocode, " . $res->base() . "\n";
 	return(-1);
     }
 
@@ -816,9 +839,9 @@ sub initGeoCodeAndGetProvidersList($$)
     }
 
     if ( !$res->is_success ) {
-	main::errorMessage("zap2it failed to give us a page: ".$res->code().":".
+	warn("zap2it failed to give us a page: ".$res->code().":".
 			 HTTP::Status::status_message($res->code())."\n");
-	main::errorMessage("looks like we located the right form, check postal/zip code on zap2it.com web site (maybe they're down)\n");
+	warn("looks like we located the right form, check postal/zip code on zap2it.com web site (maybe they're down)\n");
 	return(-1);
     }
 
@@ -840,13 +863,13 @@ sub initGeoCodeAndGetProvidersList($$)
     }
 
     if ( !defined($self->{ProviderForm}) ) {
-      main::errorMessage("zap2it failed to give us a form to choose a Provider\n");
-      main::errorMessage("check with zap2it site postal/zip code $geocode is valid\n");
+      warn("zap2it failed to give us a form to choose a Provider\n");
+      warn("check with zap2it site postal/zip code $geocode is valid\n");
 	return(-1);
     }
 
     if ( $content=~m/(We do not have information for the zip code[^\.]+)/i ) {
-	main::errorMessage("zap2it says:\"$1\"\ninvalid postal/zip code\n");
+	warn("zap2it says:\"$1\"\ninvalid postal/zip code\n");
 	return(-1);
     }
 
@@ -861,9 +884,9 @@ sub initGeoCodeAndGetProvidersList($$)
         }
     }
     if ( !defined($self->{ProviderList}) ) {
-	main::errorMessage("zap2it gave us a page with no service provider options\n");
-	main::errorMessage("check postal/zip code or www site (maybe they're down)\n");
-	main::errorMessage("(LWP::UserAgent version is ".$self->{ua}->_agent().")\n");
+	warn("zap2it gave us a page with no service provider options\n");
+	warn("check postal/zip code or www site (maybe they're down)\n");
+	warn("(LWP::UserAgent version is ".$self->{ua}->_agent().")\n");
 	return(-1);
     }
 
@@ -876,6 +899,18 @@ sub getProviderList($)
     return(@{$self->{ProviderList}->{$self->{GeoCode}}});
 }
 
+sub index_bothcases($$)
+{
+    my ($str, $substr) = @_;
+    my $r;
+    foreach (index($str, lc $substr), index($str, uc $substr)) {
+	next if $_ == -1;
+	$r = $_ if not defined $r or $_ < $r;
+    }
+    return -1 if not defined $r;
+    return $r;
+}
+
 # now allows you to get a list of avail of channels for
 # any of the valid provider ids for the give postal/zipcode
 sub getChannelList($$)
@@ -892,7 +927,7 @@ sub getChannelList($$)
     }
 
     if ( !defined($found) ) {
-      main::errorMessage("invalid provider id ($providerId), not valid of postal/zip code $self->{GeoCode}\n");
+      warn("invalid provider id ($providerId), not valid of postal/zip code $self->{GeoCode}\n");
 	return(undef);
     }
 
@@ -903,6 +938,7 @@ sub getChannelList($$)
 
     my $req=$self->Form2Request($self->{ProviderForm});
     if ( !defined($req) ) {
+	warn "failed to get provider form\n";
 	return(undef);
     }
 
@@ -921,11 +957,11 @@ sub getChannelList($$)
 	}
     }
 
-warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++ ;
+    warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++ ;
     if ( !($res->is_success || $res->code eq '500') ) {
-	main::errorMessage("zap2it failed to give us a page: ".$res->code().":".
+	warn("zap2it failed to give us a page: ".$res->code().":".
 			 HTTP::Status::status_message($res->code())."\n");
-	main::errorMessage("check postal/zip code or www site (maybe they're down)\n");
+	warn("check postal/zip code or www site (maybe they're down)\n");
 	return(undef);
     }
 
@@ -943,13 +979,13 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
     }
 
     if ( !defined($self->{GridForm}) ) {
-      main::errorMessage("zap2it doesn't have a grid form\n");
+	warn("zap2it doesn't have a grid form\n");
 	return(undef);
     }
 
     $self->{formSettings}->{rowdisplay} = 0;  # All Channels
     $req = $self->Form2Request($self->{GridForm});
-
+    die "failed to get grid form\n" if not $req;
     $res=&doRequest($self->{ua}, $req, $self->{Debug});
 
     warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
@@ -968,9 +1004,9 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 
     warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500 and !$got500error++';
     if ( !($res->is_success || $res->code eq '500') ) {
-	main::errorMessage("zap2it failed to give us a page: ".$res->code().":".
+	warn("zap2it failed to give us a page: ".$res->code().":".
 			 HTTP::Status::status_message($res->code())."\n");
-	main::errorMessage("check postal/zip code or www site (maybe they're down)\n");
+	warn("check postal/zip code or www site (maybe they're down)\n");
 	return(undef);
     }
 
@@ -998,7 +1034,7 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
     }
 
     if ( !defined($self->{ChannelByTextForm}) ) {
-      main::errorMessage("zap2it failed to give us a form to choose a Text Listings\n");
+      warn("zap2it failed to give us a form to choose a Text Listings\n");
 	return(undef);
     }
 
@@ -1006,14 +1042,31 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 
     my $rowNumber=0;
     my $html=$content;
-    $html=~s/<TR/<tr/og;
-    $html=~s/<\/TR/<\/tr/og;
 
-    for my $row (split(/<tr/, $html)) {
-	# nuke everything leading up to first >
-	# which amounts to html attributes of <tr used in split
-	$row=~s/^[^>]*>//so;
-	$row=~s/<\/tr>.*//so;
+    # Avoid using regular expressions to avoid triggering segfault in
+    # Perl.  Though it's not yet proven, IMHO, that perl's regexp
+    # engine is the code at fault.
+    #
+    my @rows;
+    my @indexes = (0);
+    my $left = $html;
+    my $pos = 0;
+    while ((my $idx = index($left, '<tr')) != -1) {
+	push @indexes, $idx + $pos;
+	$left = substr($left, $idx + 3);
+	$pos += $idx + 3;
+    }
+
+    foreach (0 .. $#indexes - 1) {
+	my ($this, $next) = @indexes[$_, $_ + 1];
+	push @rows, substr($html, $this, $next - $this);
+    }
+
+    foreach my $row (@rows) {
+ 	# nuke everything leading up to first >
+ 	# which amounts to html attributes of <tr used in split
+	$row = substr($row, index($row, '>'));
+	$row = substr($row, 0, index($row, '</tr>'));
 
 	$rowNumber++;
 
@@ -1021,6 +1074,10 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 	$row=~s/[\r\n]+\s*//og;
 
 	my $result=new XMLTV::ZapListings::ScrapeRow()->parse($row);
+	if ( !$result ) {
+	    warn("ignoing html table row that failed to parse:'$row'");
+	    next;
+	}
 
 	my $desc=$result->summarize();
 	next if ( !$desc );
@@ -1035,7 +1092,7 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 	    # img for icon
 	    my $ref=$result->getSRC(2);
 	    if ( !defined($ref) ) {
-		main::errorMessage("row decode on item 2 failed on '$desc'\n");
+		warn("row decode on item 2 failed on '$desc'\n");
 		dumpPage($content);
 		return(undef);
 	    }
@@ -1053,12 +1110,12 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 		$offset=5;
 	    }
 	    else {
-	      main::errorMessage("coding error finding <a> in $desc\n");
+	      warn("coding error finding <a> in $desc\n");
 		return(undef);
 	    }
 	    $ref=$result->getHREF($offset);
 	    if ( !defined($ref) ) {
-		main::errorMessage("row decode on item $offset failed on '$desc'\n");
+		warn("row decode on item $offset failed on '$desc'\n");
 		dumpPage($content);
 		return(undef);
 	    }
@@ -1067,7 +1124,7 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 		$nchannel->{stationid}=$1;
 	    }
 	    else {
-		main::errorMessage("row decode on item 6 href failed on '$desc'\n");
+		warn("row decode on item 6 href failed on '$desc'\n");
 		dumpPage($content);
 		return(undef);
 	    }
@@ -1086,12 +1143,12 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 		$offset=3;
 	    }
 	    else {
-	      main::errorMessage("coding error finding <a> in $desc\n");
+	      warn("coding error finding <a> in $desc\n");
 		return(undef);
 	    }
 	    my $ref=$result->getHREF($offset);
 	    if ( !defined($ref) ) {
-		main::errorMessage("row decode on item $offset failed on '$desc'\n");
+		warn("row decode on item $offset failed on '$desc'\n");
 		dumpPage($content);
 		return(undef);
 	    }
@@ -1099,7 +1156,7 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
 		$nchannel->{stationid}=$1;
 	    }
 	    else {
-		main::errorMessage("row decode on item $offset href failed on '$desc'\n");
+		warn("row decode on item $offset href failed on '$desc'\n");
 		dumpPage($content);
 		return(undef);
 	    }
@@ -1114,7 +1171,7 @@ warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code
     }
 
     if ( ! @channels ) {
-	main::errorMessage("zap2it gave us a page with no channels\n");
+	warn("zap2it gave us a page with no channels\n");
 	dumpPage($content);
 	return(undef);
     }
@@ -1145,7 +1202,7 @@ sub dumpPage($)
     my $filename = "ZapListings.dump.$dumpPage_counter";
     local *OUT;
     if (open (OUT, ">$filename")) {
-	main::errorMessage("dumping HTML page to $filename\n");
+	warn("dumping HTML page to $filename\n");
 	print OUT $content
 	  or warn "cannot dump HTML page to $filename: $!";
 	close OUT or warn "cannot close $filename: $!";
@@ -1178,10 +1235,10 @@ sub setValue($$$$)
 
     if ( $self->{Debug} ) {
 	if ( defined($hash->{$key}) ) {
-	    main::errorMessage("replaced value '$key' from '$hash->{$key}' to '$value'\n");
+	    warn("replaced value '$key' from '$hash->{$key}' to '$value'\n");
 	}
 	else {
-	    main::errorMessage("set value '$key' to '$value'\n");
+	    warn("set value '$key' to '$value'\n");
 	}
     }
     $hash->{$key}=$value;
@@ -1352,6 +1409,10 @@ sub scrapehtml($$$)
 
 	# run it through our row scaper that separates out the html
 	my $result=new XMLTV::ZapListings::ScrapeRow()->parse($row);
+	if ( !$result ) {
+	    warn("ignoing html table row that failed to parse:'$row'");
+	    next;
+	}
 
 	# put together a summary of what we found
 	my $desc=$result->summarize();
@@ -1460,9 +1521,9 @@ sub scrapehtml($$$)
 		}
 	    }
 	    else {
-	      main::errorMessage("FAILED to find/estimate endtime\n");
-	      main::errorMessage("\tsource: $htmlsource\n");
-	      main::errorMessage("\thtml:'$desc'\n");
+	      warn("FAILED to find/estimate endtime\n");
+	      warn("\tsource: $htmlsource\n");
+	      warn("\thtml:'$desc'\n");
 	    }
 
 	    if ( $desc=~s;<b><a><text>\s*(.*?)\s*</text></a></b>;;io ) {
@@ -1876,7 +1937,7 @@ sub scrapehtml($$$)
 	    if ( @leftExtras ) {
 		if ( scalar(@leftExtras) != 1 ) {
 		    for (@leftExtras) {
-			main::errorMessage("scraper failed with left over details: $_\n");
+			warn("scraper failed with left over details: $_\n");
 		    }
 		}
 		else {
@@ -1887,16 +1948,16 @@ sub scrapehtml($$$)
 
 	    #for my $key (keys (%$prog)) {
 		#if ( defined($prog->{$key}) ) {
-		#    main::errorMessage("KEY $key: $prog->{$key}\n");
+		#    warn("KEY $key: $prog->{$key}\n");
 		#}
 	    #}
 
 	    if ( $desc ne "<td><font></font>" &&
 		 $desc ne "<td><font></font><font></td>" ) {
-		main::errorMessage("scraper failed with left overs: $desc\n");
+		warn("scraper failed with left overs: $desc\n");
 	    }
 	    #$desc=~s/<text>(.*?)<\/text>/<text>/og;
-	    #main::errorMessage("\t$desc\n");
+	    #warn("\t$desc\n");
 
 
 	    # final massage.
@@ -2048,6 +2109,7 @@ sub readSchedule($$$$$)
 
 	my $req=$self->Form2Request($self->{ChannelByTextForm});
 	if ( !defined($req) ) {
+	    warn "failed to get channel by text form\n";
 	    return(-1);
 	}
 	
@@ -2064,9 +2126,9 @@ sub readSchedule($$$$$)
 
 	warn "zap2it gave us a server error, but let's go for it anyway\n" if $res->code eq '500' and !$got500error++;
     if ( !($res->is_success || $res->code eq '500') ) {
-	    main::errorMessage("zap2it failed to give us a page: ".$res->code().":".
+	    warn("zap2it failed to give us a page: ".$res->code().":".
 			     HTTP::Status::status_message($res->code())."\n");
-	    main::errorMessage("check postal/zip code or www site (maybe they're down)\n");
+	    warn("check postal/zip code or www site (maybe they're down)\n");
 	    return(-1);
 	}
 	$content=$res->content();
@@ -2076,7 +2138,7 @@ sub readSchedule($$$$$)
 	   $err=~s/\s+/ /og;
 	   $err=~s/^\s+//og;
 	   $err=~s/\s+$//og;
-	   main::errorMessage("ERROR: $err\n");
+	   warn("ERROR: $err\n");
 	   return(-1);
         }
 	if ( -d "urldata" ) {
